@@ -9,8 +9,8 @@ test_that('complete case works',{
   
   db = open_project('../verbAggression.db')
 
-  ref_items = get_items(db) %>% 
-    filter(behavior == 'Scold') %>% 
+  ref_items = get_items(db) |> 
+    filter(behavior == 'Scold') |> 
     pull(item_id)
   
   f = fit_enorm(db,method='Bayes')
@@ -20,11 +20,11 @@ test_that('complete case works',{
   expect_true(!anyNA(coef(p2p)),'no NA values')
   expect_true(all(between(as.matrix(select(coef(p2p),-(1:2))),0,1)), 'coef contains probabilities')
   
-  pass = get_testscores(db, behavior == 'Scold') %>%
-    mutate(pass=booklet_score>=7) %>%
-    select(person_id,pass) %>%
-    inner_join(get_testscores(db)) %>%
-    group_by(booklet_score) %>%
+  pass = get_testscores(db, behavior == 'Scold') |>
+    mutate(pass=booklet_score>=7) |>
+    select(person_id,pass) |>
+    inner_join(get_testscores(db)) |>
+    group_by(booklet_score) |>
     summarise(mean_pass=mean(pass))
   
   tst = inner_join(pass, coef(p2p), by=c('booklet_score'='score_new'))
@@ -35,4 +35,4 @@ test_that('complete case works',{
 
 })
 
-RcppArmadillo::armadillo_reset_cores()
+RcppArmadillo::armadillo_reset_cores()
\ No newline at end of file
